==> jc-1.4.0.tar.gz: soot/shimple/ShimpleTransformer.h <==
// public class soot.shimple.ShimpleTransformer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 5e668fb49a383a37 soot_shimple_ShimpleTransformer

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_shimple_ShimpleTransformer_H_
#define _JC_soot_shimple_ShimpleTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_shimple_ShimpleTransformer$object;

// Typedefs
typedef struct _jc_soot_shimple_ShimpleTransformer$sub_refs	_jc_soot_shimple_ShimpleTransformer$sub_refs;
typedef struct _jc_soot_shimple_ShimpleTransformer$sub_nonrefs	_jc_soot_shimple_ShimpleTransformer$sub_nonrefs;
typedef struct _jc_soot_shimple_ShimpleTransformer$refs	_jc_soot_shimple_ShimpleTransformer$refs;
typedef struct _jc_soot_shimple_ShimpleTransformer$nonrefs	_jc_soot_shimple_ShimpleTransformer$nonrefs;
typedef struct _jc_soot_shimple_ShimpleTransformer$object	_jc_soot_shimple_ShimpleTransformer$object;

typedef const struct _jc_soot_shimple_ShimpleTransformer$vmethods	_jc_soot_shimple_ShimpleTransformer$vmethods;
typedef const struct _jc_soot_shimple_ShimpleTransformer$vtable	_jc_soot_shimple_ShimpleTransformer$vtable;
typedef const struct _jc_soot_shimple_ShimpleTransformer$vtype	_jc_soot_shimple_ShimpleTransformer$vtype;

// Constructors
extern void _jc_soot_shimple_ShimpleTransformer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_shimple_ShimpleTransformer$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_shimple_ShimpleTransformer$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_shimple_ShimpleTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_ShimpleTransformer$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_shimple_ShimpleTransformer$object *_jc_soot_shimple_ShimpleTransformer$method$v$374f1dd76f109d80(_jc_env *);

// Virtual methods structure
struct _jc_soot_shimple_ShimpleTransformer$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_shimple_ShimpleTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_shimple_ShimpleTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_shimple_ShimpleTransformer$vmethods	soot_shimple_ShimpleTransformer;
};

// Vtype
struct _jc_soot_shimple_ShimpleTransformer$vtype {
	_jc_type			type;
	_jc_soot_shimple_ShimpleTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_ShimpleTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_ShimpleTransformer$refs {
    _jc_soot_shimple_ShimpleTransformer$sub_refs	soot_shimple_ShimpleTransformer;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_ShimpleTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_ShimpleTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_shimple_ShimpleTransformer$sub_nonrefs	soot_shimple_ShimpleTransformer;
};

// Object instance structure
struct _jc_soot_shimple_ShimpleTransformer$object {
	_jc_soot_shimple_ShimpleTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_ShimpleTransformer$vtype	*vtype;
	_jc_soot_shimple_ShimpleTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_ShimpleTransformer$vtype _jc_soot_shimple_ShimpleTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_ShimpleTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_ShimpleTransformer$class_object;

#endif	/* _JC_soot_shimple_ShimpleTransformer_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/ShimpleTransformer.h <==
// public class soot.shimple.ShimpleTransformer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 5e668fb49a383a37 soot_shimple_ShimpleTransformer

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_shimple_ShimpleTransformer_H_
#define _JC_soot_shimple_ShimpleTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_shimple_ShimpleTransformer$object;

// Typedefs
typedef struct _jc_soot_shimple_ShimpleTransformer$sub_refs	_jc_soot_shimple_ShimpleTransformer$sub_refs;
typedef struct _jc_soot_shimple_ShimpleTransformer$sub_nonrefs	_jc_soot_shimple_ShimpleTransformer$sub_nonrefs;
typedef struct _jc_soot_shimple_ShimpleTransformer$refs	_jc_soot_shimple_ShimpleTransformer$refs;
typedef struct _jc_soot_shimple_ShimpleTransformer$nonrefs	_jc_soot_shimple_ShimpleTransformer$nonrefs;
typedef struct _jc_soot_shimple_ShimpleTransformer$object	_jc_soot_shimple_ShimpleTransformer$object;

typedef const struct _jc_soot_shimple_ShimpleTransformer$vmethods	_jc_soot_shimple_ShimpleTransformer$vmethods;
typedef const struct _jc_soot_shimple_ShimpleTransformer$vtable	_jc_soot_shimple_ShimpleTransformer$vtable;
typedef const struct _jc_soot_shimple_ShimpleTransformer$vtype	_jc_soot_shimple_ShimpleTransformer$vtype;

// Constructors
extern void _jc_soot_shimple_ShimpleTransformer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_shimple_ShimpleTransformer$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_shimple_ShimpleTransformer$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_shimple_ShimpleTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_ShimpleTransformer$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_shimple_ShimpleTransformer$object *_jc_soot_shimple_ShimpleTransformer$method$v$374f1dd76f109d80(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_shimple_ShimpleTransformer$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_shimple_ShimpleTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_ShimpleTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_shimple_ShimpleTransformer$vmethods	soot_shimple_ShimpleTransformer;
};

// Vtype
struct _jc_soot_shimple_ShimpleTransformer$vtype {
	_jc_type			type;
	_jc_soot_shimple_ShimpleTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_ShimpleTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_ShimpleTransformer$refs {
    _jc_soot_shimple_ShimpleTransformer$sub_refs	soot_shimple_ShimpleTransformer;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_ShimpleTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_ShimpleTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_shimple_ShimpleTransformer$sub_nonrefs	soot_shimple_ShimpleTransformer;
};

// Object instance structure
struct _jc_soot_shimple_ShimpleTransformer$object {
	_jc_soot_shimple_ShimpleTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_ShimpleTransformer$vtype	*vtype;
	_jc_soot_shimple_ShimpleTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_ShimpleTransformer$vtype _jc_soot_shimple_ShimpleTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_ShimpleTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_ShimpleTransformer$class_object;

#endif	/* _JC_soot_shimple_ShimpleTransformer_H_ */
